#
# spec file for package subtitlecomposer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           subtitlecomposer
Version:        0.8.1
Release:        3.2
Summary:        A text-based subtitle editor
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://invent.kde.org/multimedia/subtitlecomposer
Source0:        https://download.kde.org/stable/subtitlecomposer/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/subtitlecomposer/%{name}-%{version}.tar.xz.sig
Source2:        subtitlecomposer.keyring
# PATCH-FIX-UPSTREAM refreshment of ffmpeg related code
Patch0:         0001-Replaced-deprecated-FFmpeg-channel-layout-code.patch
Patch1:         0002-VideoPlayer-check-AVFMT_NO_BYTE_SEEK-flag-for-seek_b.patch
Patch2:         0003-VideoPlayer-drop-an-unused-function-argument.patch
Patch3:         0004-VideoPlayer-stop-using-AVFrame.pkt_pos.patch
Patch4:         0005-VideoPlayer-remove-usage-of-internal-AVInputFormat.r.patch
Patch5:         0006-VideoPlayer-stop-injecting-stream-side-data-in-packe.patch
Patch6:         0007-VideoPlayer-check-return-of-swr_alloc_set_opts2.patch
Patch7:         0008-StreamProcessor-stop-using-pkt_duration.patch
Patch8:         0009-StreamProcessor-stop-using-AVFrame-duration.patch
Patch9:         0010-Require-FFmpeg-5.1.5.patch
# PATCH-FIX-UPSTREAM https://invent.kde.org/multimedia/subtitlecomposer/-/merge_requests/48
Patch10:        use-pocketsphinx-5.0.0-api.patch
BuildRequires:  cmake >= 3.10
BuildRequires:  extra-cmake-modules
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Auth)
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kross)
BuildRequires:  cmake(KF5Sonnet)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat) >= 59.27.100
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(openssl)
%if 0%{?suse_version} > 1500
%ifnarch ppc64 s390x
BuildRequires:  pkgconfig(pocketsphinx) >= 5
%endif
%endif

%description
A text-based subtitles editor that supports basic operations. It supports
SubRip (SRT), MicroDVD, SSA/ASS, MPlayer, TMPlayer and YouTube captions, and
has speech Recognition using PocketSphinx.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build

# Fix rpmlint error (devel-file-in-non-devel-package) and install header files as doc (since they are installed just for help)
mkdir files_for_doc
cp -a %{buildroot}%{_kf5_appsdir}/%{name}/scripts/api/ files_for_doc/
rm -r %{buildroot}%{_kf5_appsdir}/%{name}/scripts/api/
# Point to the correct path of the header files directory (doc)
perl -pi -e "s|'api'|'%{_docdir}/subtitlecomposer/api'|" %{buildroot}%{_kf5_appsdir}/%{name}/scripts/README

%find_lang %{name}

%{kf5_post_install}

%files
%doc ChangeLog README.md files_for_doc/api
%license LICENSE
%config(noreplace) %{_kf5_configdir}/%{name}rc
%dir %{_kf5_iconsdir}/hicolor/256x256
%dir %{_kf5_iconsdir}/hicolor/256x256/apps
%{_kf5_applicationsdir}/org.kde.%{name}.desktop
%{_kf5_appsdir}/%{name}/
%{_kf5_appstreamdir}/org.kde.%{name}.appdata.xml
%{_kf5_bindir}/%{name}
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_sharedir}/mime/packages/%{name}.xml
%if 0%{?suse_version} > 1500
%ifnarch ppc64 s390x
%{_kf5_libdir}/%{name}/
%endif
%endif

%files lang -f %{name}.lang

%changelog
* Wed Dec 18 2024 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix build with pocketsphinx 5.0.3 in TW since
  the API changed in the 5.0.0 release. Also, removed some
  parameters that don't seem to be configurable by pocketsphinx
  anymore:
  * use-pocketsphinx-5.0.0-api.patch
* Tue Aug 20 2024 Christophe Marin <christophe@krop.fr>
- Add upstream changes:
  * 0001-Replaced-deprecated-FFmpeg-channel-layout-code.patch
  * 0002-VideoPlayer-check-AVFMT_NO_BYTE_SEEK-flag-for-seek_b.patch
  * 0003-VideoPlayer-drop-an-unused-function-argument.patch
  * 0004-VideoPlayer-stop-using-AVFrame.pkt_pos.patch
  * 0005-VideoPlayer-remove-usage-of-internal-AVInputFormat.r.patch
  * 0006-VideoPlayer-stop-injecting-stream-side-data-in-packe.patch
  * 0007-VideoPlayer-check-return-of-swr_alloc_set_opts2.patch
  * 0008-StreamProcessor-stop-using-pkt_duration.patch
  * 0009-StreamProcessor-stop-using-AVFrame-duration.patch
  * 0010-Require-FFmpeg-5.1.5.patch
* Tue Jun 11 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.1
  * Fixed (rare) memory issues and crashes
  * Fixed crashes on waveform widget
  * Fixed video player rendering in Qt 6.7
  * Fixed scripts manager assert failures
  * Fixed inability to view non-script files in scripts manager
  * Fixed seeking in some media formats
  * Fixed video player subtitle rendering
  * Fixed broken rendering on hi-res videos
  * Fixed HDR video rendering (SMPTE-ST-2084 gamma transfer)
  * Added check for maximum number of characters per line
  * Added MinT translate engine
  * Improved translation support and UI
  * Improved video player scaling
  * Dropped KIO file operations
- Drop 0001-Increased-required-std-to-C-17-100.patch (merged
  upstream)
* Mon May 27 2024 Christophe Marin <christophe@krop.fr>
- Add upstream build fix:
  * 0001-Increased-required-std-to-C-17-100.patch
* Mon Nov  6 2023 Luigi Baldoni <aloisio@gmx.com>
  ﻿- Update to version 0.8.0
  * Fixed video player on GLES only hardware
  * Fixed skewed video on video player
  * Fixed closing fullscreen video player
  * Fixed subtitles under fullscreen video toolbar
  * Fixed video player media state notifications
  * Fixed subtitle video overlay font size accuracy
  * Fixed deadlock/crash while changing audio stream on
    paused/stopped media
  * Improved Waveform widget performance
  * Fixed waveform misalignment due to rounding error
  * Fixed waveform widget drawing on null image and painting of
    removed lines
  * Fixed waveform default zoom scale
  * Fixed subtitle text line separator draw on LinesWidget
  * Fixed unbreak lines (newline searches in QTextDocument)
  * Fixed crash in split lines
  * Fixed VobSub import ignoring Text styles
  * Fixed VobSub crash when moving to previous image
  * Fixed YouTubeCaptions format parsing/saving
  * Fixed undo/redo actions creation order, incorrect state
  * Fixed some memory and saving issues
  * Fixed embedded ASS decoding
  * Fixed example remove hearing impaired script
  * Fixed broken about dialog
  * Added Qt6 support
  * Added WebVTT format support
  * Added subtitle positioning UI and support
  * Added subtitle class/comments/voice UI and support
  * Improved rich text editing/preview
  * Rich text rendering on waveform/video/editors
  * Added DeepL translate engine
  * Added Google Cloud translate engine
  * Recreated translation interface
  * Added/improved ffmpeg 5 support
  * Subtitle lines are always time sorted; remove sort lines
    menu action
  * Replaced Kross with QJSEngine, removed ruby and python
    support
  * Improved script manager and tools menu
- Drop subtitlecomposer-ARM_GLES.patch,
  subtitlecomposer-fix_empty_lines_crash.patch,
  0001-Fix-compilation-with-ffmpeg5-63.patch,
  0001-VideoPlayer-Fix-usage-of-deprecated-removed-AVCodec-.patch,
  and 0001-Use-non-deprecated-ffmpeg-api.patch (merged upstream)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Add patch:
  * 0001-Use-non-deprecated-ffmpeg-api.patch
- Rename 4f4f560e40ba0b760cf688eb024be3cc734ca347.patch to
  0001-Fix-compilation-with-ffmpeg5-63.patch
- Rename d8f9797d9c0d45fa9f4402f79c539544b74d2cc7.patch to
  0001-VideoPlayer-Fix-usage-of-deprecated-removed-AVCodec-.patch
* Sun Apr 16 2023 Benoît Monin <benoit.monin@gmx.fr>
- Add d8f9797d9c0d45fa9f4402f79c539544b74d2cc7.patch: Fix video
  player with newer version of ffmpeg
* Tue Jul 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 4f4f560e40ba0b760cf688eb024be3cc734ca347.patch: Fix build
  with ffmpeg 5, patch from upstream git.
* Thu Nov  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Add subtitlecomposer-fix_empty_lines_crash.patch
  (fixes boo#1192342)
* Sat Oct 16 2021 Luigi Baldoni <aloisio@gmx.com>
- Add subtitlecomposer-ARM_GLES.patch
- Allow build on more targets
* Tue Oct  5 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.1
  * Fixed theme/icons/look outside KDE environment
  * Fixed various bugs and rare crashes
  * Fixed Undo stack and improved text editing undo
  * Improved/replaced Video player(s) (performance, Wayland
    support, OpenGL/FFmpeg)
  * Improved Waveform performance
  * Improved LinesWidget/Model performance
  * Improved Wayland support
  * Improved open/save file dialogs to use native dialogs
  * Improved text charsets/encodings/end-of-line selection,
    detection and handling
  * Improved VobSub support
  * Improved inline editor to support text styles
  * Improved subtitle style rendering
  * Improved character/sec support and added coloring
  * Improvide command line - ability to open all subtitle/media
    files
  * Added Pause/Duration columns to list view
  * Removed invalid subpicture/x-pgs mime
  * Updated/added many translations - thanks to KDE community
- Drop 0001-Use-a-local-qthelper.cpp-copy.patch and qthelper.hpp
  (no longer necessary)
- Add .sig file and subtitlecomposer.keyring as sources
- Spec cleanup
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Sat Mar 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Move URL to the new upstream location at invent.kde.org
- Remove the dependency on python-base (python2) by removing the
  python examples (so we don't install any python scripts anymore).
  The python scripts can't be used anyway since we build
  kross-interpreters without python support.
* Wed Mar 11 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add a local qthelper.cpp copy. mpv >= 0.33 doesn't provide this
  header anymore and suggest keeping a local copy until using a
  better wrapper.
- Add 0001-Use-a-local-qthelper.cpp-copy.patch
* Thu Jun 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.0
  * Fixed parsing of absolute paths containing '#' character
  * Fixed open dialogs not showing all supported files
  * Fixed subtitle text not respecting system font configuration
  * Fixed waveform not rendering correctly/completely on some
    formats
  * Fixed waveform displaying subtitles at wrong times
  * Fixed waveform not working with some
  * Fixes to MPV, GStreamer and Xine video player backends
  * Waveform scrolling is configurable
  * PocketSphinx language models and VAD are configurable
  * Added show status bar action to main window popup menu
  * Improved (scripting) performance
  * Spell checker will use translation text when it is selected
  * Waveform and video docks can be hidden
  * Split lines won't split text on spaces while there are
    multiple lines
  * Subtitle lines will always stay sorted by their time
  * Improved fullscreen video player
  * Added ability to step by frame
  * Added play rate controls to video menu
  * Updated Croatian translation
  * Updated Italian translation
  * Updated Russian translation
- Dropped fix_build_with_qt5.11.patch (merged upstream)
* Tue Jun 12 2018 asterios.dramis@gmail.com
- Added a patch (fix_build_with_qt5.11.patch), taken from upstream,
  to fix build failure with Qt 5.11.
* Sun Feb 11 2018 aloisio@gmx.com
- Update to version 0.6.6
  * Fixed open video dialog filters
  * Fixed "Insert Line" on waveform adding at the wrong index -
    thanks @qsniyg
  * Added MMB seeking on waveform - thanks @qsniyg
  * Fixed some compilation issues
  * Updated translations - thanks @gogogogi, @muzena
  * Fixed vobsub when opening from video file and symbol cache
    filename
  * Fixed subtitle loading times of huge files
  * Improved vobsub text detection
  * Fixed ASS rich text parsing on import subtitle stream action
  * Replaced buggy mplayer vobsub import code with ffmpeg
  * Fixed memory leaks/usage of WaveformWidget's scroll animation
  * Optimized import subtitle stream from video action
  * Replaced gstreamer with ffmpeg libraries in application core
    usage
  * Added abort button to speech recognition
  * Waveform smooth scrolling
  * Added join/split lines actions to waveform context menu
  * Fixed some crashes, memory leaks and overall code cleanups
  * Cleaned up settings widget and texts
- Dropped subtitlecomposer-Qt56.patch (merged upstream)
- Spec cleanup
* Fri Nov  3 2017 aloisio@gmx.com
- Update to version 0.6.5
  add:
  * Added support for binary subtitle formats
  * fine control video playback speed
  * controls for video playback speed
  mod:
  * GStreamer backend audio improvements.
  * Moved open video actions under File menu
  * More tolerant parsing of SubRip subtitles.
  * Improved split lines command
  * Updated Czech translation - thanks @goliashcz
  * Updated Croatian translations - thanks @muzena
  fix:
  * Waveform widget dragging and speed improvements, fixed
    buffer overflow
  * WaveformWidget: zoom out wasn't working on movies without
    audio
  * Fixed cases where subtitle hide time would end up before
    show time.
  * Improved context menus.
  * Fixed moving of anchored lines.
  * Open subtitle wouldn't autoload video in some cases
  * Open video now includes .divx and .webm extensions
  * Tools menu scripts are filtered based on installed kross
    interpreters
  * Moved custom icons to more standard location, using
    QIcon::fromTheme()
  * Error Check > Absolute Duration config fields were changing
    incorrect values.
  * MPV Backend: fixed deprecated options, updated vo devices -
    thanks @luzfcb
  * better rendering on high DPI screens.
  * MPV Backend: framerate/video length  wasn't reported to
    subtitle composer anymore
  * detection/handling of current playing line
  * Parsing text containing <font> without color attribute
  * compilation without xine - thanks @pinotree
  * ASS parsing - thanks @Martchus
- Added subtitlecomposer-Qt56.patch to be able to build against
  Qt 5.6 on Leap
* Tue Jun 13 2017 jengelh@inai.de
- Reword vague description.
* Mon Oct 31 2016 asterios.dramis@gmail.com
- Update directories not owned by package to cover also
  Factory/Tumbleweed.
* Thu Jun 23 2016 asterios.dramis@gmail.com
- Update to 0.6.4:
  * ADD: WaveformWidget: context menu
  * MOD: Updated German translations - thanks @Martchus
  * MOD: Updated Croatian translations - thanks @muzena
  * FIX: Inserting subtitle line would corrupt subtitle indexes
  * FIX: Display audio of WebM/FLV files in waveform - thanks
    @Martchus
  From 0.6.3:
  * ADD: WaveformWidget: customization settings page
  * ADD: Speech recognition with PocketSphinx
  * MOD: Waveform and Player widgets can be docked to any side of
    the main window
  * MOD: WaveformWidget: can be manually scrolled even if
    autoscroll is enabled
  * MOD: WaveformWidget: ability to drag whole subtitle line
  * MOD: Updated croatian translation - thanks @muzena
  * FIX: Video player fullscreen and icon display under was not
    right under some desktop environments - thanks @Martchus
  * FIX: WaveformWidget: when dragging subtitle borders (or
    clicking near them), show/hide time was jumping to mouse
    position
  * FIX: po/Messages.sh will generate .po files compatible with Qt
    Linguist, and will run from any path
  * FIX: Build cleanups - thanks @pinotree
  From 0.6.2:
  * ADD: Ability to demux text streams from loaded video
  * MOD: WaveformWidget: added scrollbar and manual scrolling mode,
    improved zoom, widget state is loaded/saved
  * MOD: WaveformWidget: double click will seek in video player
  * MOD: WaveformWidget: subtitle show/hide time can be dragged
  * MOD: Added default shortcut for play/pause video.
  * MOD: Support for building with cmake older version than 3.3
  * FIX: Changing player backend setting will reopen loaded video
    in new player backend.
  * FIX: Timeline after last anchored subtitle was scaled
    incorrectly.
  * FIX: WaveformWidget: optimizations and speed improvements
  * FIX: Recent files list was not saved properly in some cases
    (subtitle list full).
  * FIX: WaveformWidget: fixed crash after closing subtitle
  * FIX: WaveformWidget: editing of non-anchored lines is not
    allowed
  * FIX: StreamProcessor was not freeing it's resources.
  * FIX: Updated configure and install scripts
  * FIX: Removed "Decoder backend" entry from video player settings
    page.
  From 0.6.1:
  * FIX: Anchor points syncing wasn't working right in some cases
  From 0.6.0:
  * ADD: Anchor points syncing
  * ADD: Waveform widget.
  * MOD: Improved precision of the Time class.
  * MOD: GStreamerPlayerBackend will pause when reaching
    end-of-stream instead of stopping/resetting player.
  * MOD: Converted playerbackends to plugins
  * MOD: updated German translation
  * FIX: Video player widget will repaint background correctly.
  * FIX: Code refactoring, cleanups and optimizations.
  * FIX: fixed/enabled Drag & Drop
  From 0.5.9:
  * FIX: Improved error reporting during video open.
  * MOD: Added italian translation.
  From 0.5.8:
  * ADD: MPV player support
  * MOD: Replaced remaining KDE4 deprecated code, removed
    KDELibs4Support dependency. Finalized KF5 porting.
  * MOD: Update croatian translation and README.md
  * MOD: Added option not to resume playback after subtitle
    doubleclick if player is paused
  * FIX: Gettext translations were not created during build
    process.
  * FIX: FindGStreamer.cmake was not searching for and including
    arch-specific include dir
  * FIX: Errors/Spelling in "Error Check" settings
  * FIX: Build process fixes
  * FIX: improved player/decoder backends, solved crashes when
    switching backends
  * FIX: Added option to antialias subtitles
  * FIX: Phonon player backend was displaying embeded subtitles
  * FIX: OBS (OpenSuse) package creation was failing
- Updated build/runtime requirements to KF5/Qt5.
- Added new build requirement mpv-devel.
- Removed fdupes macro (not needed anymore).
- Removed NULL-pointer.patch and
  Find-platform-dependant-include-files-of-GStreamer.patch (fixed
  upstream).
* Sun Jan  3 2016 asterios.dramis@gmail.com
- Added Find-platform-dependant-include-files-of-GStreamer.patch in
  order to fix finding of platform-dependant include files of
  GStreamer (fixes compilation failure).
* Sun Nov 16 2014 hrvoje.senjan@gmail.com
- Update to 0.5.7
  * GStreamer 1.0 API support
- Switch BuildRequires to reflect above change
- Added NULL-pointer.patch from upstream, to resolve post-buid-check
  failure
* Wed Dec  4 2013 asterios.dramis@gmail.com
- Update to 0.5.6
  [#] Continuation of original package since initial author stopped development
  * SubStation Alpha format fixes and color support
  * source cleanup
  From 0.5.5:
  * text color support
  * SubRip text color support
  * reworked MicroDVD open/save
  From 0.5.4:
  * mplayer2 support
  * mplayer VDPAU decoding support
  * minor cmake build fixes
- Added libicu-devel build requirement.
- Removed all previous patches (fixed upstream).
* Sun Jan 29 2012 asterios.dramis@gmail.com
- Updated no-copy-dt-needed-entries.patch to fix a new linking error with
  libX11.
* Mon Dec  5 2011 asterios.dramis@gmail.com
- Added a patch (no-copy-dt-needed-entries.patch) to fix linking with
  - -no-copy-dt-needed-entries.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to GPL-2.0+ (SPDX style).
* Thu Jun  2 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Recommend instead of Suggest the subtitlecomposer-lang package.
  * Added update-mime-database in %%post/%%postun scripts for the mime file
    installed by the package.
  * Minor other updates.
* Tue Jan 18 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Added a subtitlecomposer-lang package.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Buildrequires:, %%prep and %%install sections.
  * Fixed rpmlint warnings (devel-file-in-non-devel-package,
    non-executable-script).
  * Fixed rpm post build check about directories not owned by a package.
- Add a patch to fix installation of python scripting examples.
* Thu Jun 24 2010 cmorve69@yahoo.es
- Fix compilation with GCC 4.5
* Sat Jul  4 2009 cmorve69@yahoo.es
- First version
